<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>App.About</name>
    <message>
        <source>System Monitor</source>
        <translation>Gestore Attività</translation>
    </message>
    <message>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Il Gestore Attività è uno strumento per monitorare lo stato del sistema in tempo reale, visualizzare e controllare processi e servizi in esecuzione sul sistema.
Localizzazione italiana a cura di Massimo A. Carofano.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <source>Hide details</source>
        <translation>Nascondi dettagli</translation>
    </message>
    <message>
        <source>Overall utilization</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Individual utilization</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <source>Read</source>
        <translation>Lettura</translation>
    </message>
    <message>
        <source>Write</source>
        <translation>Scrittura</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <source>60 seconds</source>
        <translation>60 secondi</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 giorni %2 ore %3 minuti</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <source>Utilization</source>
        <translation>Utilizzo</translation>
    </message>
    <message>
        <source>Current frequency</source>
        <translation>Frequenza attuale</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenza</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Marca</translation>
    </message>
    <message>
        <source>Sockets</source>
        <translation>Socket</translation>
    </message>
    <message>
        <source>Logical processors</source>
        <translation>Processori logici</translation>
    </message>
    <message>
        <source>Virtualization</source>
        <translation>Virtualizzazione</translation>
    </message>
    <message>
        <source>L1i cache</source>
        <translation>L1i cache</translation>
    </message>
    <message>
        <source>L1d cache</source>
        <translation>L1d cache</translation>
    </message>
    <message>
        <source>L2 cache</source>
        <translation>L2 cache</translation>
    </message>
    <message>
        <source>L3 cache</source>
        <translation>L3 cache</translation>
    </message>
    <message>
        <source>Load average</source>
        <translation>Carico medio</translation>
    </message>
    <message>
        <source>File descriptors</source>
        <translation>Descrittori file</translation>
    </message>
    <message>
        <source>Processes</source>
        <translation>Processi</translation>
    </message>
    <message>
        <source>Threads</source>
        <translation>Thread</translation>
    </message>
    <message>
        <source>Host name</source>
        <translation>Nome Host</translation>
    </message>
    <message>
        <source>OS type</source>
        <translation>Tipo OS</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>Up time</source>
        <translation>Utilizzo</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <source>60 seconds</source>
        <translation>60 secondi</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <source>No search results</source>
        <translation>Nessun risultato</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <source>active</source>
        <translation>attivo</translation>
    </message>
    <message>
        <source>reloading</source>
        <translation>ricaricamento</translation>
    </message>
    <message>
        <source>inactive</source>
        <translation>inattivo</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>fallito</translation>
    </message>
    <message>
        <source>activating</source>
        <translation>in attivazione</translation>
    </message>
    <message>
        <source>deactivating</source>
        <translation>in disattivazione</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <source>stub</source>
        <translation>stub</translation>
    </message>
    <message>
        <source>not-found</source>
        <translation>non-trovato</translation>
    </message>
    <message>
        <source>bad-setting</source>
        <translation>impostazione non ottimale</translation>
    </message>
    <message>
        <source>error</source>
        <translation>errore</translation>
    </message>
    <message>
        <source>merged</source>
        <translation>uniti</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>mascherato</translation>
    </message>
    <message>
        <source>loaded</source>
        <translation>caricato</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <source>enabled</source>
        <translation>abilitato</translation>
    </message>
    <message>
        <source>disabled</source>
        <translation>disabilitato</translation>
    </message>
    <message>
        <source>static</source>
        <translation>statico</translation>
    </message>
    <message>
        <source>transient</source>
        <translation>transitorio</translation>
    </message>
    <message>
        <source>indirect</source>
        <translation>indiretto</translation>
    </message>
    <message>
        <source>enabled-runtime</source>
        <translation>runtime-abilitata</translation>
    </message>
    <message>
        <source>masked</source>
        <translation>mascherata</translation>
    </message>
    <message>
        <source>generated</source>
        <translation>generata</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <source>dead</source>
        <translation>morta</translation>
    </message>
    <message>
        <source>start-pre</source>
        <translation>avvia-prima</translation>
    </message>
    <message>
        <source>start</source>
        <translation>avvia</translation>
    </message>
    <message>
        <source>start-post</source>
        <translation>avvia-dopo</translation>
    </message>
    <message>
        <source>running</source>
        <translation>in esecuzione</translation>
    </message>
    <message>
        <source>exited</source>
        <translation>uscita</translation>
    </message>
    <message>
        <source>reload</source>
        <translation>ricaricata</translation>
    </message>
    <message>
        <source>stop</source>
        <translation>stop</translation>
    </message>
    <message>
        <source>stop-watchdog</source>
        <translation>ferma-watchdog</translation>
    </message>
    <message>
        <source>stop-sigterm</source>
        <translation>ferma-sigterm</translation>
    </message>
    <message>
        <source>stop-sigkill</source>
        <translation>ferma-sigkill</translation>
    </message>
    <message>
        <source>stop-post</source>
        <translation>ferma-dopo</translation>
    </message>
    <message>
        <source>final-sigterm</source>
        <translation>sigterm-finale</translation>
    </message>
    <message>
        <source>final-sigkill</source>
        <translation>sigkill-finale</translation>
    </message>
    <message>
        <source>failed</source>
        <translation>fallito</translation>
    </message>
    <message>
        <source>auto-restart</source>
        <translation>riavvia-automaticamente</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <source>Used</source>
        <translation>Utilizzato</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Disponibile</translation>
    </message>
    <message>
        <source>Shared</source>
        <translation>Condiviso</translation>
    </message>
    <message>
        <source>Cached</source>
        <translation>Cache</translation>
    </message>
    <message>
        <source>Buffers</source>
        <translation>Buffer</translation>
    </message>
    <message>
        <source>Cached swap</source>
        <translation>Swap cache</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <source>Inactive</source>
        <translation>Non attivo</translation>
    </message>
    <message>
        <source>Dirty</source>
        <translation>Sporco</translation>
    </message>
    <message>
        <source>Mapped</source>
        <translation>Mappato</translation>
    </message>
    <message>
        <source>Total swap</source>
        <translation>Swap totale</translation>
    </message>
    <message>
        <source>Free swap</source>
        <translation>Swap libera</translation>
    </message>
    <message>
        <source>Slab</source>
        <translation>Slab</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <source>Model</source>
        <translation>Modello</translation>
    </message>
    <message>
        <source>Read speed</source>
        <translation>Velocità di lettura</translation>
    </message>
    <message>
        <source>Write speed</source>
        <translation>Velocità di scrittura</translation>
    </message>
    <message>
        <source>Capacity</source>
        <translation>Capacità</translation>
    </message>
    <message>
        <source>Sectors read</source>
        <translation>Settori letti</translation>
    </message>
    <message>
        <source>Reads/s</source>
        <translation>Letti/s</translation>
    </message>
    <message>
        <source>Sectors read/s</source>
        <translation>Settori letti/s</translation>
    </message>
    <message>
        <source>Reads merged/s</source>
        <translation>Letture unite/s</translation>
    </message>
    <message>
        <source>Sectors written</source>
        <translation>Settori scritti</translation>
    </message>
    <message>
        <source>Writes completed </source>
        <translation>Scritture completate</translation>
    </message>
    <message>
        <source>Writes merged</source>
        <translation>Scritture unite</translation>
    </message>
    <message>
        <source>Writes/s</source>
        <translation>Scrittura/s</translation>
    </message>
    <message>
        <source>Sectors written/s</source>
        <translation>Settori scritti/s</translation>
    </message>
    <message>
        <source>Writes merged/s</source>
        <translation>Scritture unite/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Visualizza scorciatoie</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Terminare questo processo potrebbe causare una perdita di dati.
Sicuro di voler terminarlo?</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Termina processo</translation>
    </message>
    <message>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Terminare questo processo potrebbe causare una perdita di dati.
Sicuro di voler terminarlo?</translation>
    </message>
    <message>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Terminare quest&apos;app potrebbe causare una perdita di dati.
Sicuro di voler terminarla?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Forza chiusura</translation>
    </message>
    <message>
        <source>End</source>
        <comment>button</comment>
        <translation>Termina</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <source>Size</source>
        <translation>Dimensioni</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <source>IP address:</source>
        <translation>Indirizzo IP:</translation>
    </message>
    <message>
        <source>Netmask:</source>
        <translation>Netmask:</translation>
    </message>
    <message>
        <source>Broadcast:</source>
        <translation>Broadcast:</translation>
    </message>
    <message>
        <source>Prefixlen:</source>
        <translation>Prefixlen:</translation>
    </message>
    <message>
        <source>Scope:</source>
        <translation>Scope:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <source>Connection type</source>
        <translation>Tipo connessione</translation>
    </message>
    <message>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <source>Link quality</source>
        <translation>Qualità collegamento</translation>
    </message>
    <message>
        <source>Signal strength</source>
        <translation>Potenza segnale</translation>
    </message>
    <message>
        <source>Noise level</source>
        <translation>Livello rumore</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>Bandwidth</source>
        <translation>Larghezza di banda</translation>
    </message>
    <message>
        <source>RX packets</source>
        <translation>RX pachetti</translation>
    </message>
    <message>
        <source>RX bytes</source>
        <translation>RX byte</translation>
    </message>
    <message>
        <source>RX errors</source>
        <translation>RX errori</translation>
    </message>
    <message>
        <source>RX dropped</source>
        <translation>RX persi</translation>
    </message>
    <message>
        <source>RX overruns</source>
        <translation>RX saltati</translation>
    </message>
    <message>
        <source>RX frame</source>
        <translation>RX frame</translation>
    </message>
    <message>
        <source>TX packets</source>
        <translation>TX pacchetti</translation>
    </message>
    <message>
        <source>TX bytes</source>
        <translation>TX byte</translation>
    </message>
    <message>
        <source>TX errors</source>
        <translation>TX errori</translation>
    </message>
    <message>
        <source>TX overruns</source>
        <translation>TX saltati</translation>
    </message>
    <message>
        <source>TX carrier</source>
        <translation>TX vettore</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>TX dropped</source>
        <translation>TX persi</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <source>Command line</source>
        <translation>Linea di comando</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Tempo di esecuzione</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Clicca sull&apos;App che vuoi terminare</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Receive</source>
        <translation>Ricevuti</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lettura disco</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Scrittura disco</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Swap</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Non attivo</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
    <message>
        <source>Total Received</source>
        <translation>Totale Ricevuti</translation>
    </message>
    <message>
        <source>Total Sent</source>
        <translation>Totale inviati</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Inviati</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Dischi</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <source>Very high</source>
        <translation>Molto alta</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normale</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Bassa</translation>
    </message>
    <message>
        <source>Very low</source>
        <translation>Molto bassa</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizza</translation>
    </message>
    <message>
        <source>Invalid</source>
        <translation>Non valido</translation>
    </message>
    <message>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Errore: [%2] %3</translation>
    </message>
    <message>
        <source>Failed to change process priority</source>
        <translation>Variazione della priorità del Processo fallita</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <source>Applications</source>
        <translation>Applicazioni</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>I miei Processi</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Tutti i Processi</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <source>Loading</source>
        <translation>Caricamento</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <source>Failed to pause process</source>
        <translation>Pausa del processo fallita</translation>
    </message>
    <message>
        <source>Failed to resume process</source>
        <translation>Ripristino del processo fallito</translation>
    </message>
    <message>
        <source>Failed to kill process</source>
        <translation>Soppressione processo fallita</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Failed in sending signal to process</source>
        <translation>Invio segnale al processo fallito</translation>
    </message>
    <message>
        <source>Failed to end process</source>
        <translation>Terminazione processo fallita</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 applicazioni e %2 processi in esecuzione)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <source>No response</source>
        <translation>Nessuna risposta</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Sospendi</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tray</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <source>View command location</source>
        <translation>Visualizza locazione</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <source>End process</source>
        <translation>Termina processo</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Riprendi processo</translation>
    </message>
    <message>
        <source>Kill process</source>
        <translation>Termina processo</translation>
    </message>
    <message>
        <source>Change priority</source>
        <translation>Cambia priorità</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Sospendi processo</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <source>Custom Priority</source>
        <translation>Priorità personalizzata</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Change</source>
        <comment>button</comment>
        <translation>Cambia</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Scrittura disco</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lettura disco</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Upload</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Nice</source>
        <translation>Nice</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorità</translation>
    </message>
    <message>
        <source>Shared memory</source>
        <translation>Memoria condivisa</translation>
    </message>
    <message>
        <source>Virtual memory</source>
        <translation>Memoria virtuale</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Not support</source>
        <translation>Non supportato</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Protection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CPU warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Memory warning threshold (%)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warning interval (min)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <source>Failed to set service startup type</source>
        <translation>Impossibile settare il tipo di avvio del servizio</translation>
    </message>
    <message>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Errore: impossibile settare il tipo di avvio del servizio per via del crash di un sotto-processo.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <source>Service instance name</source>
        <translation>Nome istanza di Servizio</translation>
    </message>
    <message>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Restart</source>
        <translation>Riavvia</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>Startup type</source>
        <translation>Tipo di avvio</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Carica</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Attivo</translation>
    </message>
    <message>
        <source>Sub</source>
        <translation>In esecuzione</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Startup Type</source>
        <translation>Tipo di avvio</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(Modifiable)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Range: %1-%2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <source>Force end application</source>
        <translation>Forza chiusura App</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Espandi</translation>
    </message>
    <message>
        <source>Compact</source>
        <translation>Comprimi</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualizza</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <source>Processes</source>
        <translation>Processi</translation>
    </message>
    <message>
        <source>Services</source>
        <translation>Servizi</translation>
    </message>
</context>
</TS>
